import sys
import typing


def rule_add(type: typing.Union[int, str] = 'GOAL'):
    ''' Add a boid rule to the current boid state

    :param type: Type
    :type type: typing.Union[int, str]
    '''

    pass


def rule_del():
    ''' Delete current boid rule

    '''

    pass


def rule_move_down():
    ''' Move boid rule down in the list

    '''

    pass


def rule_move_up():
    ''' Move boid rule up in the list

    '''

    pass


def state_add():
    ''' Add a boid state to the particle system

    '''

    pass


def state_del():
    ''' Delete current boid state

    '''

    pass


def state_move_down():
    ''' Move boid state down in the list

    '''

    pass


def state_move_up():
    ''' Move boid state up in the list

    '''

    pass
