import sys
import typing


def svg(filepath: str = "", filter_glob: str = "*.svg"):
    ''' Load a SVG file

    :param filepath: File Path, Filepath used for importing the file
    :type filepath: str
    :param filter_glob: filter_glob
    :type filter_glob: str
    '''

    pass
